@@ -1,3 +1,4 @@
+import os
 import gdown
 import pickle
 
@@ -34,10 +35,12 @@ class Datasets(object):
         split_url = url.split('/')
         return self.base_url + split_url[5]
     
-    def get_emo_tweets(self):
+    def get_emo_tweets(self, force_download = False):
         try:
-            gdown.download(self.url_id, self.output, quiet = False)
-            gdown.download(self.get_complete_url(pickle.load(open(self.output, 'rb'))['emotion_tweets']['link']), 'tweets.csv', quiet = False)
+            if(not os.path.exists(self.output) or force_download):
+                gdown.download(self.url_id, self.output, quiet = False)
+            if(not os.path.exists('tweets.csv') or force_download): 
+                gdown.download(self.get_complete_url(pickle.load(open(self.output, 'rb'))['emotion_tweets']['link']), 'tweets.csv', quiet = False)
             return pd.read_csv('tweets.csv')
         except:
             print("[ERROR]:Error in loading dataset, please check downloaded file")
\ No newline at end of file
